#
# spec file for package OpenImageIO
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Asterios Dramis <asterios.dramis@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define so_ver 1_2

Name:           OpenImageIO
Version:        1.2.2
Release:        1.7
Summary:        Library for Reading and Writing Images
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
Url:            http://www.openimageio.org/
#DL-URL: https://github.com/OpenImageIO/oiio/archive/Release-%{version}/OpenImageIO-%{version}.tar.gz
Source0:        %{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM oiio-ppc.patch asterios.dramis@gmail.com -- Fix compilation with ppc (patch taken from Fedora)
Patch0:         oiio-ppc.patch
# PATCH-FIX-UPSTREAM oiio-arm.patch asterios.dramis@gmail.com -- Fix compilation with arm (patch taken from Fedora)
Patch1:         oiio-arm.patch
# PATCH-FIX-UPSTREAM hdf5_libs.patch asterios.dramis@gmail.com -- Fix linking with HDF5 libs
Patch2:         hdf5_libs.patch
BuildRequires:  Field3D-devel
%if 0%{?suse_version} > 1230
BuildRequires:  OpenColorIO-devel
%endif
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  glew-devel
BuildRequires:  hdf5-devel
%if 0%{?suse_version} > 1220
BuildRequires:  ilmbase-devel
%else
BuildRequires:  libilmbase-devel
%endif
BuildRequires:  libjpeg-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt4-devel
BuildRequires:  libtiff-devel
BuildRequires:  libwebp-devel
BuildRequires:  opencv-devel
%if 0%{?suse_version} > 1220
BuildRequires:  openexr-devel
%else
BuildRequires:  OpenEXR-devel
%endif
BuildRequires:  openjpeg-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pugixml-devel
BuildRequires:  python-devel
BuildRequires:  txt2man
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. There is a particular emphasis on formats
and functionality used in professional, large-scale animation and visual
effects work for film. OpenImageIO is used extensively in animation and VFX
studios all over the world, and is also incorporated into several commercial
products.

%package devel
Summary:        Development Files for OpenImageIO
Group:          Development/Libraries/C and C++
Requires:       libOpenImageIO%{so_ver} = %{version}

%description devel
This package provides development libraries and headers needed to build
software using OpenImageIO.

%package -n libOpenImageIO%{so_ver}
Summary:        Library for Reading and Writing Images
Group:          System/Libraries

%description -n libOpenImageIO%{so_ver}
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. There is a particular emphasis on formats
and functionality used in professional, large-scale animation and visual
effects work for film. OpenImageIO is used extensively in animation and VFX
studios all over the world, and is also incorporated into several commercial
products.

%package -n python-OpenImageIO
Summary:        Python Bindings for OpenImageIO
Group:          Development/Libraries/Python
%{py_requires}

%description -n python-OpenImageIO
This package contains python bindings for OpenImageIO.

%prep
%setup -q -n oiio-Release-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Make sure that bundled libraries are not used
rm -f src/include/pugiconfig.hpp \
      src/include/pugixml.hpp
rm -rf src/include/tbb/

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
mkdir build
cd build
# CMAKE_SKIP_RPATH is OK here because it is set to FALSE internally and causes
# CMAKE_INSTALL_RPATH to be cleared, which is the desired result.
cmake \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DLIB_INSTALL_DIR=%{_libdir} \
    -DPYLIB_INSTALL_DIR=%{python_sitearch} \
    -DDOC_INSTALL_DIR=%{_docdir}/%{name} \
    -DBUILDSTATIC=OFF \
    -DLINKSTATIC=OFF \
    -DUSE_EXTERNAL_PUGIXML=ON \
    -DUSE_TBB=OFF \
    -DCMAKE_SKIP_RPATH=ON \
%ifarch ppc ppc64
    -DNOTHREADS=ON \
%endif
    ../src
make %{?_smp_mflags} VERBOSE=1
cd ..

make doxygen

%install
%make_install -C build

# Move devel documentation to the right location
mkdir -p %{buildroot}%{_docdir}/%{name}-devel
mv %{buildroot}%{_docdir}/%{name}/openimageio.pdf %{buildroot}%{_docdir}/%{name}-devel/

# Install additional devel documentation
cp -a src/doc/doxygen/html/ %{buildroot}%{_docdir}/%{name}-devel/

%fdupes -s %{buildroot}

%post -n libOpenImageIO%{so_ver} -p /sbin/ldconfig

%postun -n libOpenImageIO%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc CHANGES CREDITS LICENSE README.rst
%{_bindir}/*
%doc %{_mandir}/man1/*.1%{ext_man}

%files devel
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-devel/
%{_includedir}/OpenImageIO/
%{_libdir}/*.so

%files -n libOpenImageIO%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libOpenImageIO.so.1.2*

%files -n python-OpenImageIO
%defattr(-,root,root,-)
%{python_sitearch}/OpenImageIO.so

%changelog
* Sun Oct 27 2013 asterios.dramis@gmail.com
- Update to version 1.2.2:
  * New features:
    + New oiiotool --siappend : append subimages of top two images on stack.
    + Utilities: added Strutil::contains() and icontains().
  * Fixes:
    + Fixes in handling XMP & IPTC metadata.
    + oiiotool --origin and --fullpixels did not correctly propagate their
    changes to the output images.
    + oiiotool --colorconvert (and the underlying ImageBufAlgo::colorconvert)
    could crash if given a color conversion recognized as a no-op.
    + DPX output could crash when writing crop images.
    + DPX input was not recognizing the proper image offset or originalsize.
    + oiiotool --fit wasn't padding correctly or modifying offsets properly.
  * Build fixes:
    + Fix compiler error on MIPS platform.
    + Add FIELD3D_HOME description to 'make help'
    + Always use the HDF5 release libraries (for Field3D), not the debug ones.
  From version 1.2.1:
  * oiiotool: Fix memory leak when processing frame range.
  * Docs improvement: full documentation of ImageBufAlgo.
  * oiiotool --help now returns a success error code, not a failure.
  * oiiotool: fix incorrect help message about --ociolook.
  * oiiotool: Fix typo in "oiio:Colorspace" attribute name that interfered
    with correct color space conversion in --colorconvert.
  * Many fixes for compiler warnings on various platforms: fmath_test.cpp,
    field3dinput.cpp, sysutil.cpp, argparse.cpp, oiiotool.cpp.
  * Fixes problems on little-endian architecture with texture3d.cpp.
  * Fix compilation problems on architectures with gcc, but no 'pause'
    instruction.
  * Fix build search path for correctly finding libopenjpeg 1.5.
  * Work around bug in older MSVC versions wherein Filesystem::open needed
    to explicitly seek to the beginning of a file.
  * Build fixes for FreeBSD.
  * Fix testsuite/oiiotool on Windows -- windows shell doesn't expand
    wildcards.
- Removed oiio-typedef.patch (fixed upstream).
- Rebased oiio-ppc.patch and oiio-arm.patch to apply cleanly.
- Added an upstream patch (hdf5_libs.patch) to fix linking with HDF5 libs.
* Tue Aug  6 2013 asterios.dramis@gmail.com
- BuildRequire OpenColorIO-devel only for openSUSE > 12.3.
* Tue Aug  6 2013 asterios.dramis@gmail.com
- Update to version 1.2.0:
  * Major new release.
  * Lots of changes (See CHANGES files).
- Replaced OpenImageIO-ppc.patch with oiio-ppc.patch (taken from Fedora).
- Added a patch (oiio-arm.patch) to fix compilation with arm (taken from
  Fedora).
- Added a patch (oiio-typedef.patch) to fix compiler warning about unused local
  typedef (fix for gcc-4.8) (taken from Fedora).
- Added freetype2-devel and libopenssl-devel build requirements.
- Removed tbb-devel build requirement (deprecated).
- Use -DCMAKE_SKIP_RPATH=ON to fix compilation.
* Sun Jun  9 2013 asterios.dramis@gmail.com
- Update to version 1.1.11:
  * IFF input: bug in endian swap of 16 bit IFF files.
  * oiiotool: fix a minor bug where tiled files were output inappropriately.
    (Had been patched in master some time ago.)
  * fmath.h additions: safe_inversesqrt, safe_log, safe_log2, safe_log10,
    safe_logb.  These are versions that clamp their inputs so that they
    can't throw exceptions or return Inf or NaN.
  * Fix to not incorrectly print ImageCache stats for certain broken files.
  From version 1.1.10:
  * IBA::fillholes() and oiiotool --fillholes can smoothly fill in alpha
    holes with nearby colors. Great for extrapolating the empty areas of
    texture atlas images so that filtered texture lookups pull in a plausible
    color at part edges.
  * IBA::clamp and oiiotool --clamp clamp pixel values to a scalar or
    per-channel min and/or max, or clamp alpha to [0,1].
  * IBA::rangecompress()/rangeexpand(), and oiiotool --rangecompress /
  - -rangeexpand compress the excess >1 values of HDR images to a log
    scale (leaving the <= 1 part linear), and re-expand to the usual
    linear scale.  This is very helpful to reduce ringing artifacts that
    can happen when an HDR image is resized with a good filter with negative
    lobes (such as lanczos3), by doing a range compression, then the resize,
    then range expansion. It's not mathematically correct and loses energy,
    but it often makes a much more pleasing result.
  * maketx --hicomp does highlight compression -- automatically doing a
    range compress before each high-quality resize step, and then a
    range expansion and clamp-to-zero (squash negative pixels) after
    each resize.
  * DPX - when writing DPX files, properly set the pixel aspect ratio.
  From version 1.1.9:
  * IBA::resize and oiiotool --resize/--fit: Bug fixes to resize filter
    size selection fix artifacts wherein extreme zooms could end up with
    black stripes in places where the filters fell entirely between samples.
  * oiiotool --fit: fix subtle bugs with aspect ratio preservation for
    images with differing data and display windows; and allow "filter=..."
    to override the default filter used for fit.
  * Resize improvement: fix potential artifacts at the image edges resulting
    from odd clamping behavior.
  * Even more frame range wildcard flexibility with oiiotool --frames and
  - -framepadding options.
  * oiiotool --resize and --fit (and the underlying IBA::resize()) have been
    sped up significantly and are now also multithreaded.
  From version 1.1.8:
  * oiiotool --chappend (and ImageBufAlgo::channel_append() underneath) allow
    you to take two files and concatenate their color channels.
  * oiiotool --chnames allows you to rename some or all of a file's color
    channels.
  * oiiotool can loop over entire frame ranges by specifying wildcard
    filenames such as "foo.#.tif" or "bar.1-10#.exr".
  * Cmake: OVERRIDE_SHARED_LIBRARY_SUFFIX allows the shared library suffix
    to be overridden (e.g., if you need to force .so names on OSX rather
    than the usual default of .dylib).
  From version 1.1.7:
  * Back out dangerous change to thread.h that was in 1.1.6, which could
    cause performance problems.
  * Compile fix for WIN32 in strutil.cpp
  * Compile fix for Windows XP - add implementation of InterlockedExchangeAdd64
- Added txt2man as build requirement.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Added OpenColorIO-devel as build requirement.
* Wed Feb 20 2013 asterios.dramis@gmail.com
- Initial rpm release (version 1.1.6).
- Added a patch "OpenImageIO-ppc.patch" to fix compilation with ppc (patch
  taken from Fedora).
